intelmq.bots.experts.deduplicator package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.experts.deduplicator package

## Submodules

## intelmq.bots.experts.deduplicator.expert module

Deduplicator expert bot

param redis_cache_host

  string

param redis_cache_port

  int

param redis_cache_db

  int

param redis_cache_ttl

  int

param redis_cache_password

  string. default: {None}

param filter_type

  string [“blacklist”, “whitelist”]

param bypass

  boolean default: False

param filter_keys

  string with multiple keys separated by comma. Please note that time.observation key is never consider by the system because system will always ignore this key.

`intelmq.bots.experts.deduplicator.expert.` `BOT`

  alias of `intelmq.bots.experts.deduplicator.expert.DeduplicatorExpertBot`

class `intelmq.bots.experts.deduplicator.expert.` `DeduplicatorExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `init`()
  `process`()

## Module contents